@@ -56,9 +56,10 @@ typedef struct
  * Flags to alter the behavior of flatpak_installation_update().
  */
 typedef enum {
-  FLATPAK_UPDATE_FLAGS_NONE      = 0,
-  FLATPAK_UPDATE_FLAGS_NO_DEPLOY = (1 << 0),
-  FLATPAK_UPDATE_FLAGS_NO_PULL   = (1 << 1),
+  FLATPAK_UPDATE_FLAGS_NONE             = 0,
+  FLATPAK_UPDATE_FLAGS_NO_DEPLOY        = (1 << 0),
+  FLATPAK_UPDATE_FLAGS_NO_PULL          = (1 << 1),
+  FLATPAK_UPDATE_FLAGS_NO_STATIC_DELTAS = (1 << 2),
 } FlatpakUpdateFlags;
 
 /**
@@ -68,9 +69,28 @@ typedef enum {
  * Flags to alter the behavior of flatpak_installation_install_full().
  */
 typedef enum {
-  FLATPAK_INSTALL_FLAGS_NONE      = 0,
+  FLATPAK_INSTALL_FLAGS_NONE             = 0,
+  FLATPAK_INSTALL_FLAGS_NO_STATIC_DELTAS = (1 << 0),
 } FlatpakInstallFlags;
 
+/**
+ * FlatpakStorageType:
+ * @FLATPAK_STORAGE_TYPE_DEFAULT: default
+ * @FLATPAK_STORAGE_TYPE_HARD_DISK: installation is on a hard disk
+ * @FLATPAK_STORAGE_TYPE_SDCARD: installation is on a SD card
+ * @FLATPAK_STORAGE_TYPE_MMC: installation is on an MMC
+ *
+ * Flags to alter the behavior of flatpak_installation_install_full().
+ *
+ * Since: 0.6.15
+ */
+typedef enum {
+  FLATPAK_STORAGE_TYPE_DEFAULT = 0,
+  FLATPAK_STORAGE_TYPE_HARD_DISK,
+  FLATPAK_STORAGE_TYPE_SDCARD,
+  FLATPAK_STORAGE_TYPE_MMC,
+} FlatpakStorageType;
+
 
 #ifdef G_DEFINE_AUTOPTR_CLEANUP_FUNC
 G_DEFINE_AUTOPTR_CLEANUP_FUNC (FlatpakInstallation, g_object_unref)
@@ -80,8 +100,13 @@ FLATPAK_EXTERN const char  *flatpak_get_default_arch (void);
 
 FLATPAK_EXTERN const char *const *flatpak_get_supported_arches (void);
 
+FLATPAK_EXTERN GPtrArray *flatpak_get_system_installations (GCancellable *cancellable,
+                                                            GError      **error);
 FLATPAK_EXTERN FlatpakInstallation *flatpak_installation_new_system (GCancellable *cancellable,
                                                                      GError      **error);
+FLATPAK_EXTERN FlatpakInstallation *flatpak_installation_new_system_with_id (const char   *id,
+                                                                             GCancellable *cancellable,
+                                                                             GError      **error);
 FLATPAK_EXTERN FlatpakInstallation *flatpak_installation_new_user (GCancellable *cancellable,
                                                                    GError      **error);
 FLATPAK_EXTERN FlatpakInstallation *flatpak_installation_new_for_path (GFile        *path,
@@ -112,6 +137,10 @@ FLATPAK_EXTERN gboolean             flatpak_installation_drop_caches (FlatpakIns
                                                                       GError             **error);
 FLATPAK_EXTERN gboolean             flatpak_installation_get_is_user (FlatpakInstallation *self);
 FLATPAK_EXTERN GFile               *flatpak_installation_get_path (FlatpakInstallation *self);
+FLATPAK_EXTERN const char          *flatpak_installation_get_id (FlatpakInstallation *self);
+FLATPAK_EXTERN const char          *flatpak_installation_get_display_name (FlatpakInstallation *self);
+FLATPAK_EXTERN gint                 flatpak_installation_get_priority (FlatpakInstallation *self);
+FLATPAK_EXTERN FlatpakStorageType   flatpak_installation_get_storage_type (FlatpakInstallation *self);
 FLATPAK_EXTERN gboolean             flatpak_installation_launch (FlatpakInstallation *self,
                                                                  const char          *name,
                                                                  const char          *arch,
@@ -259,6 +288,14 @@ FLATPAK_EXTERN gboolean          flatpak_installation_update_appstream_sync (Fla
                                                                              gboolean            *out_changed,
                                                                              GCancellable        *cancellable,
                                                                              GError             **error);
+FLATPAK_EXTERN gboolean          flatpak_installation_update_appstream_full_sync (FlatpakInstallation *self,
+                                                                                  const char          *remote_name,
+                                                                                  const char          *arch,
+                                                                                  FlatpakProgressCallback progress,
+                                                                                  gpointer                progress_data,
+                                                                                  gboolean            *out_changed,
+                                                                                  GCancellable        *cancellable,
+                                                                                  GError             **error);
 FLATPAK_EXTERN GPtrArray    *    flatpak_installation_list_remote_related_refs_sync (FlatpakInstallation *self,
                                                                                      const char          *remote_name,
                                                                                      const char          *ref,
